<!DOCTYPE html>
<html class="no-js" lang="<?php echo e(str_replace('_', '-', app()->getLocale())); ?>">
<head>

    <!--- basic page needs
    ================================================== -->
    <meta charset="utf-8">
    <title><?php echo e(isset($post) && $post->seo_title ? $post->seo_title :  config('app.name')); ?></title>
    <meta name="description" content="<?php echo e(isset($post) && $post->meta_description ? $post->meta_description : __(config('app.description'))); ?>">
    <meta name="author" content="<?php echo e(isset($post) ? $post->user->name : __(config('app.author'))); ?>">
    <?php if(isset($post) && $post->meta_keywords): ?>
        <meta name="keywords" content="<?php echo e($post->meta_keywords); ?>">
    <?php endif; ?>

    <!-- mobile specific metas
    ================================================== -->
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!-- CSS
    ================================================== -->
    <link rel="stylesheet" href="<?php echo e(asset('css/vendor.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('css/styles.css')); ?>">
    <?php echo $__env->yieldContent('style'); ?>

    <!-- script
    ================================================== -->
    <script src="<?php echo e(asset('js/modernizr.js')); ?>"></script>
    <script defer src="<?php echo e(asset('js/fontawesome/all.min.js')); ?>"></script>

    <!-- favicons
    ================================================== -->
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo e(asset('apple-touch-icon.png')); ?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo e(asset('favicon-32x32.png')); ?>">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo e(asset('favicon-16x16.png')); ?>">
    <link rel="manifest" href="<?php echo e(asset('site.webmanifest')); ?>">

</head>

<body id="top">


    <!-- preloader
    ================================================== -->
    <div id="preloader"> 
    	<div id="loader"></div>
    </div>


    <!-- header
    ================================================== -->
    <header class="s-header <?php if (! (currentRoute('home'))): ?> s-header--opaque <?php endif; ?>">

        <div class="s-header__logo">
            <a class="logo" href="<?php echo e(route('home')); ?>">
                <img src="<?php echo e(asset('images/logo.svg')); ?>" alt="Homepage">
            </a>
        </div>

        <div class="row s-header__navigation">

            <nav class="s-header__nav-wrap">

                <h3 class="s-header__nav-heading h6"><?php echo app('translator')->get('Navigate to'); ?></h3>

                <ul class="s-header__nav">
                    <li <?php echo e(currentRoute('home')); ?>>
                        <a href="<?php echo e(route('home')); ?>" title=""><?php echo app('translator')->get('Home'); ?></a>
                    </li>
                    <li class="has-children">
                        <a href="#" title=""><?php echo app('translator')->get('Categories'); ?></a>
                        <ul class="sub-menu">
                            <?php $__currentLoopData = $categories; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $category): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <li><a href="<?php echo e(route('category', $category->slug)); ?>"><?php echo e($category->title); ?></a></li>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </ul>
                    </li>
                    <li <?php echo e(currentRoute('contacts.create')); ?>>
                        <a href="<?php echo e(route('contacts.create')); ?>" title=""><?php echo app('translator')->get('Contact'); ?></a>
                    </li>
                    <?php if(auth()->guard()->guest()): ?>
                        <?php if (\Illuminate\Support\Facades\Blade::check('request', 'register')): ?>
                            <li class="current">
                                <a href="<?php echo e(request()->url()); ?>"><?php echo app('translator')->get('Register'); ?></a>
                            </li>
                        <?php endif; ?>
                        <li <?php echo e(currentRoute('login')); ?>>
                            <a href="<?php echo e(route('login')); ?>"><?php echo app('translator')->get('Login'); ?></a>
                        </li>                        
                        <?php if (\Illuminate\Support\Facades\Blade::check('request', 'forgot-password')): ?>
                            <li class="current">
                                <a href="<?php echo e(request()->url()); ?>"><?php echo app('translator')->get('Password'); ?></a>
                            </li>
                        <?php endif; ?>
                        <?php if (\Illuminate\Support\Facades\Blade::check('request', 'reset-password/*')): ?>
                            <li class="current">
                                <a href="<?php echo e(request()->url()); ?>"><?php echo app('translator')->get('Password'); ?></a>
                            </li>
                        <?php endif; ?>
                    <?php else: ?>
                        <?php if(auth()->user()->role != 'user'): ?>
                            <li>
                                <a href="<?php echo e(url('admin')); ?>"><?php echo app('translator')->get('Administration'); ?></a>
                            </li>
                        <?php endif; ?>
                        <li>                                
                            <form action="<?php echo e(route('logout')); ?>" method="POST" hidden>
                                <?php echo csrf_field(); ?>                                
                            </form>
                            <a 
                                href="<?php echo e(route('logout')); ?>"
                                onclick="event.preventDefault(); this.previousElementSibling.submit();">
                                <?php echo app('translator')->get('Logout'); ?>
                            </a>
                        </li>
                    <?php endif; ?>
                </ul>

                <a href="#0" title="<?php echo app('translator')->get('Close Menu'); ?>" class="s-header__overlay-close close-mobile-menu"><?php echo app('translator')->get('Close'); ?></a>

            </nav>

        </div>

        <a class="s-header__toggle-menu" href="#0" title="<?php echo app('translator')->get('Menu'); ?>"><span><?php echo app('translator')->get('Menu'); ?></span></a>

        <div class="s-header__search">

            <div class="s-header__search-inner">
                <div class="row wide">

                    <form role="search" method="get" class="s-header__search-form" action="<?php echo e(Route('posts.search')); ?>">
                        <label>
                            <span class="h-screen-reader-text"><?php echo app('translator')->get('Search for:'); ?></span>
                            <input id="search" type="search" name="search" class="s-header__search-field" placeholder="<?php echo app('translator')->get('Search for...'); ?>" title="<?php echo app('translator')->get('Search for:'); ?>" autocomplete="off">
                        </label>
                        <input type="submit" class="s-header__search-submit" value="Search"> 
                    </form>

                    <a href="#0" title="<?php echo app('translator')->get('Close Search'); ?>" class="s-header__overlay-close"><?php echo app('translator')->get('Close'); ?></a>

                </div>
            </div>

        </div>

        <a class="s-header__search-trigger" href="#">
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 17.982 17.983"><path fill="#010101" d="M12.622 13.611l-.209.163A7.607 7.607 0 017.7 15.399C3.454 15.399 0 11.945 0 7.7 0 3.454 3.454 0 7.7 0c4.245 0 7.699 3.454 7.699 7.7a7.613 7.613 0 01-1.626 4.714l-.163.209 4.372 4.371-.989.989-4.371-4.372zM7.7 1.399a6.307 6.307 0 00-6.3 6.3A6.307 6.307 0 007.7 14c3.473 0 6.3-2.827 6.3-6.3a6.308 6.308 0 00-6.3-6.301z"/></svg>
        </a>

    </header>


    <!-- hero
    ================================================== -->
    <?php echo $__env->yieldContent('hero'); ?>


    <!-- content
    ================================================== -->
    <section class="s-content <?php if(currentRoute('home')): ?> s-content--no-top-padding <?php endif; ?>">

        <?php echo $__env->yieldContent('main'); ?>

    </section>


    <!-- footer
    ================================================== -->
    <footer class="s-footer">

        <div class="s-footer__main">

            <div class="row">

                <div class="column large-6 medium-6 tab-12 s-footer__info">

                    <h5><?php echo app('translator')->get('About Our Site'); ?></h5>

                    <p>
                    Lorem ipsum Ut velit dolor Ut labore id fugiat in ut 
                    fugiat nostrud qui in dolore commodo eu magna Duis 
                    cillum dolor officia esse mollit proident Excepteur 
                    exercitation nulla. Lorem ipsum In reprehenderit 
                    commodo aliqua irure.
                    </p>

                </div>

                <div class="column large-3 medium-3 tab-6 s-footer__site-links">

                    <h5><?php echo app('translator')->get('Site Links'); ?></h5>

                    <ul>
                        <?php $__currentLoopData = $pages; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $page): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <li><a href="<?php echo e(route('page', $page->slug)); ?>"><?php echo app('translator')->get($page->title); ?></a></li>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>

                </div> 

                <div class="column large-2 medium-3 tab-6 s-footer__social-links">
                    
                    <h5><?php echo app('translator')->get('Follow Us'); ?></h5>

                    <ul>
                        <?php $__currentLoopData = $follows; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $follow): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <li><a href="<?php echo e($follow->href); ?>"><?php echo e($follow->title); ?></a></li>
                        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    </ul>

                </div>

            </div>

        </div>

        <div class="s-footer__bottom">
            <div class="row">
                <div class="column">
                    <div class="ss-copyright">
                        <span>© Copyright Calvin 2020</span> 
                        <span>Design by <a href="https://www.styleshout.com/">StyleShout</a></span>
                    </div>
                </div>
            </div> 

            <div class="ss-go-top">
                <a class="smoothscroll" title="Back to Top" href="#top">
                    <svg viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg" width="15" height="15"><path d="M7.5 1.5l.354-.354L7.5.793l-.354.353.354.354zm-.354.354l4 4 .708-.708-4-4-.708.708zm0-.708l-4 4 .708.708 4-4-.708-.708zM7 1.5V14h1V1.5H7z" fill="currentColor"></path></svg>
                </a>
            </div>
        </div>

    </footer>

    <!-- JavaScript
    ================================================== -->
    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="<?php echo e(asset('js/plugins.js')); ?>"></script>
    <script src="<?php echo e(asset('js/main.js')); ?>"></script>
    <?php echo $__env->yieldContent('scripts'); ?>

</body>

</html><?php /**PATH E:\laragon\www\monblog\resources\views/front/layout.blade.php ENDPATH**/ ?>